@@ -6,11 +6,13 @@ import json
 from contextlib import suppress
 from typing import TYPE_CHECKING, Any
 
-from any_llm import completion
+from any_llm import acompletion
+from any_llm.provider import ProviderFactory, ProviderName
 from mcp.types import CallToolResult, TextContent
 
 from any_agent.config import AgentConfig, AgentFramework
 from any_agent.logging import logger
+from any_agent.utils.cast import safe_cast_argument
 
 from .any_agent import AnyAgent
 
@@ -61,7 +63,9 @@ class ToolExecutor:
                 for arg_name, arg_type in func_args.items():
                     if arg_name in arguments:
                         with suppress(Exception):
-                            arguments[arg_name] = arg_type(arguments[arg_name])
+                            arguments[arg_name] = safe_cast_argument(
+                                arguments[arg_name], arg_type
+                            )
 
             if asyncio.iscoroutinefunction(self.tool_function):
                 result = await self.tool_function(**arguments)
@@ -109,7 +113,9 @@ class TinyAgent(AnyAgent):
             **(self.config.model_args or {}),
         }
 
-        if self.completion_params["tool_choice"] == "required":
+        provider_name, _ = ProviderFactory.split_model_provider(self.config.model_id)
+        self.uses_openai = provider_name == ProviderName.OPENAI
+        if not self.uses_openai and self.completion_params["tool_choice"] == "required":
             self.config.tools.append(final_answer)
 
         if self.config.api_key:
@@ -119,10 +125,7 @@ class TinyAgent(AnyAgent):
 
     async def _load_agent(self) -> None:
         """Load the agent and its tools."""
-        wrapped_tools, mcp_servers = await self._load_tools(self.config.tools)
-        self._mcp_servers = (
-            mcp_servers  # Store servers so that they don't get garbage collected
-        )
+        wrapped_tools = await self._load_tools(self.config.tools)
 
         self._tools = wrapped_tools
 
@@ -147,7 +150,7 @@ class TinyAgent(AnyAgent):
                         "description": f"Parameter {param_name}",
                     }
 
-                    if param.default == inspect.Parameter.empty:
+                    if param.default == inspect.Parameter.empty or self.uses_openai:
                         required.append(param_name)
 
                 input_schema = {
@@ -158,20 +161,27 @@ class TinyAgent(AnyAgent):
             else:
                 input_schema = tool.__input_schema__
 
-            self.completion_params["tools"].append(
-                {
-                    "type": "function",
-                    "function": {
-                        "name": tool_name,
-                        "description": tool_desc,
-                        "parameters": input_schema,
-                    },
-                }
-            )
+            function_def = {
+                "type": "function",
+                "function": {
+                    "name": tool_name,
+                    "description": tool_desc,
+                    "parameters": input_schema,
+                },
+            }
+            if self.uses_openai:
+                function_def["function"]["parameters"]["additionalProperties"] = False  # type: ignore[index]
+                function_def["function"]["strict"] = True  # type: ignore[index]
 
+            self.completion_params["tools"].append(function_def)
             self.clients[tool_name] = ToolExecutor(tool)
 
     async def _run_async(self, prompt: str, **kwargs: Any) -> str | BaseModel:
+        if self.uses_openai:
+            self.completion_params["tool_choice"] = "auto"
+            if self.config.output_type:
+                self.completion_params["response_format"] = self.config.output_type
+
         messages = [
             {
                 "role": "system",
@@ -245,6 +255,10 @@ class TinyAgent(AnyAgent):
     ) -> str | BaseModel:
         if not self.config.output_type:
             return output
+
+        if self.uses_openai:
+            return self.config.output_type.model_validate_json(output)
+
         completion_params["messages"] = [
             {
                 "role": "system",
@@ -267,7 +281,7 @@ class TinyAgent(AnyAgent):
         )
 
     async def call_model(self, **completion_params: dict[str, Any]) -> ChatCompletion:
-        return completion(**completion_params)  # type: ignore[return-value, arg-type]
+        return await acompletion(**completion_params)  # type: ignore[return-value, arg-type]
 
     async def update_output_type_async(
         self, output_type: type[BaseModel] | None
