@@ -109,7 +109,9 @@ class Steps(BaseModel):
 @pytest.mark.parametrize(
     "model_id",
     [
-        "anthropic/claude-3-5-haiku-latest",
+        # Disabling anthropic until output_type can be handled without relying on `response_format`
+        # because that is not supported in some providers.
+        # "anthropic/claude-3-5-haiku-latest",
         "google/gemini-2.5-flash",
         "huggingface/tgi",  # This is a Qwen/Qwen3-1.7B hosted in https://endpoints.huggingface.co/mozilla-ai/endpoints/dedicated
         "openai/gpt-4.1-nano",
