@@ -8,7 +8,7 @@ from pydantic import BaseModel
 
 from any_agent import AgentConfig, AgentFramework, AnyAgent
 from any_agent.frameworks.tinyagent import TinyAgent, ToolExecutor
-from any_agent.testing.helpers import DEFAULT_SMALL_MODEL_ID, LITELLM_IMPORT_PATHS
+from any_agent.testing.helpers import DEFAULT_SMALL_MODEL_ID, LLM_IMPORT_PATHS
 
 
 class SampleOutput(BaseModel):
@@ -27,7 +27,7 @@ async def sample_tool_function(arg1: int, arg2: str) -> str:
 @pytest.mark.asyncio
 async def test_tool_argument_casting() -> None:
     agent: TinyAgent = await AnyAgent.create_async(
-        AgentFramework.TINYAGENT, AgentConfig(model_id="mistral/mistral-small-latest")
+        AgentFramework.TINYAGENT, AgentConfig(model_id=DEFAULT_SMALL_MODEL_ID)
     )  # type: ignore[assignment]
 
     # Register the sample tool function
@@ -55,9 +55,9 @@ def test_run_tinyagent_agent_custom_args() -> None:
     output = "The state capital of Pennsylvania is Harrisburg."
 
     agent = AnyAgent.create(
-        AgentFramework.TINYAGENT, AgentConfig(model_id="mistral/mistral-small-latest")
+        AgentFramework.TINYAGENT, AgentConfig(model_id=DEFAULT_SMALL_MODEL_ID)
     )
-    with patch(LITELLM_IMPORT_PATHS[AgentFramework.TINYAGENT]) as mock_acompletion:
+    with patch(LLM_IMPORT_PATHS[AgentFramework.TINYAGENT]) as mock_acompletion:
         # Create a mock response object that properly mocks the LiteLLM response structure
         mock_response = MagicMock()
         mock_message = MagicMock()
@@ -78,7 +78,7 @@ def test_run_tinyagent_agent_custom_args() -> None:
 
 def test_output_type_completion_params_isolation() -> None:
     """Test that completion_params are not polluted between calls when using output_type."""
-    config = AgentConfig(model_id="gpt-4o", output_type=SampleOutput)
+    config = AgentConfig(model_id=DEFAULT_SMALL_MODEL_ID, output_type=SampleOutput)
     agent: TinyAgent = AnyAgent.create(AgentFramework.TINYAGENT, config)  # type: ignore[assignment]
     original_completion_params = agent.completion_params.copy()
 
@@ -99,7 +99,7 @@ def test_output_type_completion_params_isolation() -> None:
             mock_message.__getitem__.return_value = content
         return MagicMock(choices=[MagicMock(message=mock_message)])
 
-    with patch(LITELLM_IMPORT_PATHS[AgentFramework.TINYAGENT]) as mock_acompletion:
+    with patch(LLM_IMPORT_PATHS[AgentFramework.TINYAGENT]) as mock_acompletion:
         # Mock responses: 2 calls per run (regular + structured output)
         mock_acompletion.side_effect = [
             create_mock_response("First response"),  # First run, regular call
@@ -117,7 +117,7 @@ def test_output_type_completion_params_isolation() -> None:
 
 def test_structured_output_without_tools() -> None:
     """Test that structured output works correctly when no tools are present and tool_choice is not set."""
-    config = AgentConfig(model_id="gpt-4.1-mini", output_type=SampleOutput)
+    config = AgentConfig(model_id=DEFAULT_SMALL_MODEL_ID, output_type=SampleOutput)
     agent: TinyAgent = AnyAgent.create(AgentFramework.TINYAGENT, config)  # type: ignore[assignment]
 
     def create_mock_response(content: str, is_structured: bool = False) -> MagicMock:
@@ -137,7 +137,7 @@ def test_structured_output_without_tools() -> None:
             mock_message.__getitem__.return_value = content
         return MagicMock(choices=[MagicMock(message=mock_message)])
 
-    with patch(LITELLM_IMPORT_PATHS[AgentFramework.TINYAGENT]) as mock_acompletion:
+    with patch(LLM_IMPORT_PATHS[AgentFramework.TINYAGENT]) as mock_acompletion:
         # Mock responses: 2 calls per run (regular + structured output)
         mock_acompletion.side_effect = [
             create_mock_response("Initial response"),  # First call - regular response
